<?php

require_once __DIR__ . '/../database/database.php';

class clienteModel {

    private PDO $db;

    public function __construct() {
        $this->db = Database::getConnection();
    }

    // LISTAR CLIENTES

    public function listarClientes(): array {
        
        $sql = "SELECT id, nombre, apellido, telefono, email FROM clientes ORDER BY id ASC";

        $stmt = $this->db->prepare($sql);

        $stmt->execute();

        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // CREAR CLIENTE

    public function crearCliente(array $data): bool {

        $sql = "INSERT INTO clientes (nombre, apellido, telefono, email, cuit, cond_iva) VALUES (:nombre, :apellido, :telefono, :email, :cuit, :cond_iva)";

        $stmt = $this->db->prepare($sql);

        return $stmt->execute([
            ':nombre' => $data['nombre'],
            ':apellido' => $data['apellido'],
            ':telefono' => $data['telefono'],
            ':email' => $data['email'],
            ':cuit' => $data['cuit'],
            ':cond_iva' => $data['cond_iva']
        ]);
    }

    // OBTENER CLIENTE POR ID

    public function obtenerPorId(int $id): ?array { // El ? lo uso para que pueda devolver NULL

        $sql = "SELECT id, nombre, apellido, telefono, email, cuit, cond_iva FROM clientes WHERE (id = :id) LIMIT 1";

        $stmt = $this->db->prepare($sql);

        $stmt->execute([':id' => $id]); // Le asigna al parámetro nombrado el valor de $id

        $cliente = $stmt->fetch(PDO::FETCH_ASSOC); // Devuelve un array asociativo

        return $cliente ?: null; // Verifica si el array no esta vacío y lo devuelve, sino devuelve null
    }

    // ACTUALIZAR DATOS DE CLIENTE

    public function actualizarCliente(int $id, array $data): bool {

        if (empty($data)) {
            return false;
        }

        $campos = [];
        $params = []; // Se utiliza para evitar inyección SQL usando parámetros nombrados de PDO

        foreach ($data as $campo => $valor) {
            $campos[] = "$campo = :$campo"; // Arma el string relacionando $campo con los parámetros nombrados (se usa en la consulta)
            $params[":$campo"] = $valor; // Arma array relacionando el parámetro nombrado con el valor (se usa en la consulta)
        }

        $params[':id'] = $id;

        $sql = "UPDATE clientes SET " . implode(', ', $campos) . " WHERE id = :id";

        $stmt = $this->db->prepare($sql);

        return $stmt->execute($params); // Relaciona los nombrados con los valores
    }

    // VERIFICAR EXISTENCIA DE CLIENTE (al crear)

    public function verificarExistencia(array $datosCliente, ?int $idExcluir = null): bool {

        $sql = "SELECT 1 FROM clientes WHERE ((nombre = :nombre AND apellido = :apellido AND email = :email) OR (email = :email) OR (cuit = :cuit))";

        if ($idExcluir !== null) {
            $sql .= " AND id <> :id_excluir";
        }

        $sql .= " LIMIT 1";

        $stmt = $this->db->prepare($sql);

        $params = [
            ':nombre' => $datosCliente['nombre'],
            ':apellido' => $datosCliente['apellido'],
            ':email' => $datosCliente['email'],
            ':cuit' => $datosCliente['cuit']
        ];

        if ($idExcluir !== null) {
            $params[':id_excluir'] = $idExcluir;
        }

        $stmt->execute($params);

        return (bool) $stmt->fetchColumn();
    }
}